# helloworld

Say Hello

## Installation

Run the following to install:

```sh
python3 -m pip install helloworld
```

## Usage

```python
from helloworld import say_hello

# Generate "Hello, World!"
say_hello()

# Generate "Hello, Everybody!"
say_hello("Everybody")
```

## Developing helloworld

To install helloworld, along with the tools you need to develop and run tests, run the following in your virtualenv:

```sh
python3 -m pip install -e .[dev]
```

